@@ -54,8 +54,8 @@ def getLiveWeatherRSS():
     return render_template('getLiveWeatherRSS.html', obs = obs, date = date, hr = hr, iconLive = iconLive,  weburl = app.config['QUERY_URL'])
 
 # forecast is called After liveWeather so we will reuse the wdata variable.
-@app.route('/getForecastRSS.aspx', methods=['POST','GET'])
-def getForecastRSS():
+@app.route('/old_getForecastRSS.aspx', methods=['POST','GET'])
+def old_getForecastRSS():
     global wdata
     forecasts = []
     mode='forecast'
@@ -75,6 +75,39 @@ def getForecastRSS():
     writeLog(mode)
     return render_template('getForecastRSS.html', loc = loc, forecasts = forecasts, icon = icon, now = now)
 
+@app.route('/getForecastRSS.aspx', methods=['POST','GET'])
+def getForecastRSS():
+    logging.info('Getting weather data via API')
+    find_key = 'forecast'
+    source_url = app.config['API_URL'] + app.config['API_KEY'] + app.config['API_FORECAST']
+    logging.debug(source_url)
+    r = requests.get(source_url)
+    logging.debug(r)
+    data = r.json()
+    forecasts=[]
+    logging.debug(data)
+    mode='forecast'
+    loc=data['response']['features']
+    logging.debug(loc)
+    for i in range(0, 5):
+        fc=data[mode]['simpleforecast']['forecastday'][i]
+        logging.debug(fc)
+        # pop is probability of precipitation
+        if fc['pop'] > 0:
+            short_prediction = '%s%% %s' % (fc['pop'], fc['conditions'])
+        else:
+            short_prediction = fc['conditions']  
+        logging.debug(short_prediction)
+        fc['short_prediction'] = short_prediction            
+        iconKey = fc['icon']
+        icon.setdefault(iconKey,  10)
+        forecasts.append(fc)    
+     
+    logging.debug(forecasts)
+    now=datetime.now().strftime("%m/%d/%y %H:%M:%S %p")
+    writeLog(mode)
+    return render_template('getForecastApi.html', loc = loc, forecasts = forecasts, icon = icon, now = now)
+
 @app.route('/getLocationsXML.aspx', methods=['POST','GET'])
 def getLocationsXML():
     mode='locations'
@@ -98,11 +131,16 @@ def verify():
 # returns a json data object
 def getWeatherData(source_url):
     logging.info('Getting weather data')
-    find_key = 'wui\.bootstrapped\.API'
+#    find_key = 'wui\.bootstrapped\.API'
+#    find_key = 'wui\.bootstrapped\.pwsdashboard'
+    find_key = 'wui\.api_data'
     r = requests.get(source_url)
     soup = BeautifulSoup(r.text)
     script = soup.find('script', text=re.compile(find_key))
+    logging.debug(script)
     json_text = re.search(r'^\s*' + find_key + '\s*=\s*({.*?})\s*;\s*$', script.string, flags=re.DOTALL | re.MULTILINE).group(1)
+    json_text = re.sub('[|]', '', json_text)
+    #logging.debug(json_text)
     data = json.loads(json_text)
     logging.debug(data)
     assert data['response']['version'] == '2.0'
@@ -111,7 +149,7 @@ def getWeatherData(source_url):
 def writeRequestParams(mode):
     with open(app.instance_path + '/../static/' + mode + "." + session['id'] + '.params','w') as f:
         for p in request.args:
-            f.write('%s = %s\n' % (p, request.args.get(p)))
+            f.write('%s = %s\n' % (p, request.args.get(p))) 
 
 def writeLog(mode):
     now = time.strftime("%Y-%m-%d-%H:%M:%S")
